@@ -18,3 +18,10 @@ class techsample(SQLModel, table=True):  # type: ignore
     filepath_r2: Optional[str] = None
     created_at: datetime = CreatedAt
     updated_at: Optional[datetime] = UpdatedAt
+
+
+class biosample_techsample(SQLModel, table=True):  # type: ignore
+    """Link table of biosample and techsample."""
+
+    biosample_id: str = Field(foreign_key="biosample.id", primary_key=True)
+    techsample_id: str = Field(foreign_key="techsample.id", primary_key=True)
